==> angular-floating-label-1.0.0.tgz: package/test/karma.conf.js <==
// Karma configuration

module.exports = function (config) {
    config.set({

        // base path, that will be used to resolve files and exclude
        basePath: '../',


        // frameworks to use
        frameworks: ['jasmine'],


        // list of files / patterns to load in the browser
        files: [
            'bower_components/angular/angular.js',
            'bower_components/angular-mocks/angular-mocks.js',

            //'src/float-label.module.js',
            'src/**/*.module.js',
            'src/**/*.js',

            'test/spec/**/*'
        ],

        // list of files to exclude
        exclude: [],

        preprocessors: {
            'src/**/*.js': ['coverage']
        },

        // Which plugins to enable
        plugins: [
            'karma-phantomjs-launcher',
            'karma-jasmine',
            'karma-coverage',
            'karma-junit-reporter'
        ],

        reporters: ['junit', 'dots', 'coverage'],

        junitReporter: {
            outputFile: 'test/test-results.xml'
        },

        coverageReporter: {
            reporters:[
                {
                    type: 'cobertura',
                    dir: 'test/coverage/xml/',
                    file: 'coverage.xml'
                },
                {
                    type: 'html',
                    dir: 'test/coverage/html/'
                }
            ]
        },

        // web server port
        port: 9876,


        // enable / disable colors in the output (reporters and logs)
        colors: true,

        // level of logging
        // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
        logLevel: config.LOG_INFO,


        // enable / disable watching file and executing tests whenever any file changes
        autoWatch: false,


        // Start these browsers, currently available:
        // - Chrome
        // - ChromeCanary
        // - Firefox
        // - Opera (has to be installed with `npm install karma-opera-launcher`)
        // - Safari (only Mac; has to be installed with `npm install karma-safari-launcher`)
        // - PhantomJS
        // - IE (only Windows; has to be installed with `npm install karma-ie-launcher`)
        browsers: ['PhantomJS'],


        // If browser does not capture in given timeout [ms], kill it
        captureTimeout: 60000,


        // Continuous Integration mode
        // if true, it capture browsers, run tests and exit
        singleRun: true
    });
};

==> angular-floating-label-1.0.2.tgz: package/test/karma.conf.js <==
// Karma configuration

module.exports = function (config) {
    config.set({

        // base path, that will be used to resolve files and exclude
        basePath: '../',


        // frameworks to use
        frameworks: ['jasmine'],


        // list of files / patterns to load in the browser
        files: [
            'bower_components/angular/angular.js',
            'bower_components/angular-mocks/angular-mocks.js',

            //'src/float-label.module.js',
            'src/**/*.module.js',
            'src/**/*.js',

            'test/spec/**/*'
        ],

        // list of files to exclude
        exclude: [],

        preprocessors: {
            'src/**/*.js': ['coverage']
        },

        // Which plugins to enable
        plugins: [
            'karma-phantomjs-launcher',
            'karma-jasmine',
            'karma-coverage',
            'karma-junit-reporter'
        ],

        reporters: ['junit', 'dots', 'coverage'],

        junitReporter: {
            outputDir: 'test/junit',
            outputFile: 'test-results.xml'
        },

        coverageReporter: {
            reporters:[
                {
                    type: 'cobertura',
                    dir: 'test/coverage/xml/',
                    file: 'coverage.xml'
                },
                {
                    type: 'html',
                    dir: 'test/coverage/html/'
                }
            ]
        },

        // web server port
        port: 9876,


        // enable / disable colors in the output (reporters and logs)
        colors: true,

        // level of logging
        // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
        logLevel: config.LOG_INFO,


        // enable / disable watching file and executing tests whenever any file changes
        autoWatch: false,


        // Start these browsers, currently available:
        // - Chrome
        // - ChromeCanary
        // - Firefox
        // - Opera (has to be installed with `npm install karma-opera-launcher`)
        // - Safari (only Mac; has to be installed with `npm install karma-safari-launcher`)
        // - PhantomJS
        // - IE (only Windows; has to be installed with `npm install karma-ie-launcher`)
        browsers: ['PhantomJS'],


        // If browser does not capture in given timeout [ms], kill it
        captureTimeout: 60000,


        // Continuous Integration mode
        // if true, it capture browsers, run tests and exit
        singleRun: true
    });
};
